[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
08/11: gnu: guile-irregex: Update to 0.9.11.
From: |
guix-commits |
Subject: |
08/11: gnu: guile-irregex: Update to 0.9.11. |
Date: |
Sat, 2 Mar 2024 11:27:15 -0500 (EST) |
civodul pushed a commit to branch master
in repository guix.
commit 47d5a96bd28b1e22b06bb5dd9fd0ed3be22188d8
Author: Tomas Volf <~@wolfsden.cz>
AuthorDate: Sun Feb 25 14:26:08 2024 +0100
gnu: guile-irregex: Update to 0.9.11.
Since upstream now provides tests for guile, they are executed, both before
install (testing the internals) and after install (making sure the guile
module and everything works well).
Guile 2.0 for some reason cannot load "foo.scm" using (load-from-path
"foo"),
so symlinks are created to work around that.
* gnu/packages/guile-xyz.scm (guile-irregex)[version]: Update to 0.9.11.
[arguments]: Convert to gexp.
<#:phases>{'move-files-around}: Copy files instead of moving.
{'check, 'check-installed}: New phases.
(guile2.0-irregex)[arguments]: Add 'create-symlinks phase.
Change-Id: Ib9d4e9c24475aa8e7fc1e70b868b690eaf6ad42e
Signed-off-by: Ludovic Courtès <ludo@gnu.org>
---
gnu/packages/guile-xyz.scm | 78 +++++++++++++++++++++++++++++++++++-----------
1 file changed, 60 insertions(+), 18 deletions(-)
diff --git a/gnu/packages/guile-xyz.scm b/gnu/packages/guile-xyz.scm
index b34472d5bd..9d683199ac 100644
--- a/gnu/packages/guile-xyz.scm
+++ b/gnu/packages/guile-xyz.scm
@@ -2895,7 +2895,7 @@ See http://minikanren.org/ for more on miniKanren
generally.")
(define-public guile-irregex
(package
(name "guile-irregex")
- (version "0.9.6")
+ (version "0.9.11")
(source (origin
(method url-fetch)
(uri (string-append
@@ -2903,25 +2903,46 @@ See http://minikanren.org/ for more on miniKanren
generally.")
version ".tar.gz"))
(sha256
(base32
- "1ia3m7dp3lcxa048q0gqbiwwsyvn99baw6xkhb4bhhzn4k7bwyqq"))))
+ "026kzl96pmwbjqdc7kh8rdh8ng813sjvdsik0dag5acza20sjm19"))))
(build-system guile-build-system)
(arguments
- '(#:phases (modify-phases %standard-phases
- (add-after 'unpack 'move-files-around
- (lambda _
- ;; Move the relevant source files to src/ and create the
- ;; rx/ directory to match the expected module hierarchy.
- (mkdir-p "src/rx/source")
- (rename-file "irregex-guile.scm"
- "src/rx/irregex.scm")
- (rename-file "irregex.scm"
- "src/rx/source/irregex.scm")
- ;; Not really reachable via guile's packaging system,
- ;; but nice to have around.
- (rename-file "irregex-utils.scm"
- "src/rx/source/irregex-utils.scm")
- #t)))
- #:source-directory "src"))
+ (list
+ #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'move-files-around
+ (lambda _
+ ;; Copy the relevant source files to src/ and create the
+ ;; rx/ directory to match the expected module hierarchy.
+ (mkdir-p "src/rx/source")
+ (copy-file "irregex-guile.scm"
+ "src/rx/irregex.scm")
+ (copy-file "irregex.scm"
+ "src/rx/source/irregex.scm")
+
+ (mkdir-p "src/rx/irregex")
+ (copy-file "irregex-utils-guile.scm"
+ "src/rx/irregex/utils.scm")
+ (copy-file "irregex-utils.scm"
+ "src/rx/source/irregex-utils.scm")))
+ (add-after 'build 'check
+ (lambda _
+ (for-each (lambda (f)
+ (invoke "guile" "--no-auto-compile" "-L" "." "-s" f))
+ (find-files "tests" "^guile-.*\\.scm"))))
+ (add-after 'install 'check-installed
+ (lambda _
+ (define-values (scm go) (target-guile-scm+go #$output))
+ (for-each
+ (lambda (f)
+ (substitute* f
+ (("\\(load-from-path \"irregex\"\\)")
+ "(use-modules (rx irregex))")
+ (("\\(load-from-path \"irregex-utils\"\\)")
+ "(use-modules (rx irregex utils))"))
+ (invoke "guile" "-L" scm "-C" go "-L" "tests" f))
+ (delete "tests/guile-cset.scm" ; Tests non-exported API
+ (find-files "tests" "^guile-.*\\.scm"))))))
+ #:source-directory "src"))
(native-inputs
(list guile-3.0))
(home-page "https://synthcode.com/scheme/irregex")
@@ -2936,6 +2957,27 @@ inspired by the SCSH regular expression system.")
(package
(inherit guile-irregex)
(name "guile2.0-irregex")
+ (arguments
+ (substitute-keyword-arguments (package-arguments guile-irregex)
+ ((#:phases phases)
+ #~(modify-phases #$phases
+ ;; For some reason guile 2.0 cannot load foo.scm using
+ ;; (load-from-path "foo"). So create symlinks to work around it.
+ (add-before 'check 'create-symlinks
+ (lambda _
+ (use-modules (ice-9 regex))
+ (for-each
+ (lambda (f)
+ (symlink (regexp-substitute #f (string-match "/([^/]+)$" f)
+ 1 ".scm")
+ f))
+ '("tests/guile/test-support"
+ "tests/test-cset"
+ "tests/test-irregex"
+ "tests/test-irregex-from-gauche"
+ "tests/test-irregex-pcre"
+ "tests/test-irregex-scsh"
+ "tests/test-irregex-utf8"))))))))
(native-inputs (list guile-2.0))))
(define-public guile2.2-irregex
- branch master updated (efdaa885b0 -> 6f5ea7ac1a), guix-commits, 2024/03/02
- 01/11: doc: Add “Getting Started with the System” section., guix-commits, 2024/03/02
- 04/11: build-system/guile: Fix typo in documentation string., guix-commits, 2024/03/02
- 05/11: build-system/guile: Fix indentation., guix-commits, 2024/03/02
- 06/11: build-system/guile: Install .scm files first., guix-commits, 2024/03/02
- 07/11: gnu: llama-cpp: Update to 03bf16., guix-commits, 2024/03/02
- 08/11: gnu: guile-irregex: Update to 0.9.11.,
guix-commits <=
- 03/11: gnu: Add python-mord., guix-commits, 2024/03/02
- 02/11: doc: Add “Inspecting Services” section., guix-commits, 2024/03/02
- 09/11: gnu: cgit: Update to 8905003cba637e5b18069e625cd4f4c05ac30251., guix-commits, 2024/03/02
- 10/11: gnu: Add passt., guix-commits, 2024/03/02
- 11/11: gnu: podman: Update to 4.9.3., guix-commits, 2024/03/02